@@ -13,14 +13,16 @@ use File::Copy ();
 use ExtUtils::MakeMaker 7.12;
 
 # ABSTRACT: FFI::Build installer code for ExtUtils::MakeMaker
-our $VERSION = '0.95_06'; # TRIAL VERSION
+our $VERSION = '0.95_07'; # TRIAL VERSION
 
 
 sub new
 {
-  my($class) = @_;
+  my($class, %opt) = @_;
+
+  my $save = defined $opt{save} ? $opt{save} : 1;
   
-  my $self = bless {}, $class;
+  my $self = bless { save => $save }, $class;
   $self->load_prop;
   
   $self;
@@ -146,6 +148,7 @@ sub test
 sub save_prop
 {
   my($self) = @_;
+  return unless $self->{save};
   open my $fh, '>', 'fbx.json';
   print $fh JSON::PP::encode_json($self->{prop});
   close $fh;
@@ -154,6 +157,7 @@ sub save_prop
 sub load_prop
 {
   my($self) = @_;
+  return unless $self->{save};
   unless(-f 'fbx.json')
   {
     $self->{prop} = {};
@@ -284,7 +288,7 @@ FFI::Build::MM - FFI::Build installer code for ExtUtils::MakeMaker
 
 =head1 VERSION
 
-version 0.95_06
+version 0.95_07
 
 =head1 SYNOPSIS
 
